summaryrefslogtreecommitdiff
path: root/src/StardewModdingAPI/Framework/AssemblyRewriting/CachePaths.cs
diff options
context:
space:
mode:
authorJesse Plamondon-Willard <github@jplamondonw.com>2016-12-12 11:52:34 -0500
committerJesse Plamondon-Willard <github@jplamondonw.com>2016-12-12 11:52:34 -0500
commit28e2695a19f7babf35d177367840a82b798beb55 (patch)
tree591b2badd77a7c9c0c36b8e09abdb6a323513307 /src/StardewModdingAPI/Framework/AssemblyRewriting/CachePaths.cs
parentaaf354761f18a18b0bcb81c9bd32819bb28deac9 (diff)
parenta3376e2a6257c01c52a3c64c4f5f1f8de9a9c906 (diff)
downloadSMAPI-28e2695a19f7babf35d177367840a82b798beb55.tar.gz
SMAPI-28e2695a19f7babf35d177367840a82b798beb55.tar.bz2
SMAPI-28e2695a19f7babf35d177367840a82b798beb55.zip
Merge branch 'develop' into stable
Diffstat (limited to 'src/StardewModdingAPI/Framework/AssemblyRewriting/CachePaths.cs')
-rw-r--r--src/StardewModdingAPI/Framework/AssemblyRewriting/CachePaths.cs10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/StardewModdingAPI/Framework/AssemblyRewriting/CachePaths.cs b/src/StardewModdingAPI/Framework/AssemblyRewriting/CachePaths.cs
index 17c4d188..18861873 100644
--- a/src/StardewModdingAPI/Framework/AssemblyRewriting/CachePaths.cs
+++ b/src/StardewModdingAPI/Framework/AssemblyRewriting/CachePaths.cs
@@ -12,8 +12,8 @@ namespace StardewModdingAPI.Framework.AssemblyRewriting
/// <summary>The file path of the assembly file.</summary>
public string Assembly { get; }
- /// <summary>The file path containing the MD5 hash for the assembly.</summary>
- public string Hash { get; }
+ /// <summary>The file path containing the assembly metadata.</summary>
+ public string Metadata { get; }
/*********
@@ -22,12 +22,12 @@ namespace StardewModdingAPI.Framework.AssemblyRewriting
/// <summary>Construct an instance.</summary>
/// <param name="directory">The directory path which contains the assembly.</param>
/// <param name="assembly">The file path of the assembly file.</param>
- /// <param name="hash">The file path containing the MD5 hash for the assembly.</param>
- public CachePaths(string directory, string assembly, string hash)
+ /// <param name="metadata">The file path containing the assembly metadata.</param>
+ public CachePaths(string directory, string assembly, string metadata)
{
this.Directory = directory;
this.Assembly = assembly;
- this.Hash = hash;
+ this.Metadata = metadata;
}
}
} \ No newline at end of file